/*
 * Copyright (C) Sapphirecode - All Rights Reserved
 * This file is part of Modelling which is released under MIT.
 * See file 'LICENSE' for full license details.
 * Created by Timo Hocker <timo@scode.ovh>, May 2020
 */

export abstract class DatabaseModel {
  protected data: Record<string, string|number|boolean> = {};

  public get id (): number {
    return this.data.id as number;
  }

  public set id (val: number) {
    this.data.id = val;
  }

  public get data (): Record<string, string|number, boolean> {
    return this.data;
  }

  public constructor (id: number) {
    this.id = id;
  }

  public abstract get(key: string): string|number|boolean;
  public abstract set(key: string, value: string|number|boolean): void;

  public abstract async read(): Promise<void>;
  public abstract async write(): Promise<void>;
}
